DATA_DIR = "/usr/share"
PKG_DATA_DIR = "/usr/share/gnome-tweak-tool"
GSETTINGS_SCHEMA_DIR = "/usr/share/glib-2.0/schemas"
TWEAK_DIR = "/usr/lib/python3.6/site-packages/gtweak/tweaks"
VERSION = "3.26.2.1"
LOCALE_DIR = "/usr/share/locale"
LIBEXEC_DIR = "/usr/lib"
